==> dispmua_1.6.8.orig.tar.bz2: dispmua-1.6.8/chrome/chrome.jar!/content/data-65.js <==
dispMUA.arDispMUAAllocation["e"] =
{
  "e-mail spooler created by stepstone - easycruit" : [ "stepstone.png" , "http://www.easycruit.com/" ] ,
  "esmtp (eudora internet mail server" : [ "eudora.png" , "http://www.eudora.com/" ] ,
  "emilious sender by epsilon eridani" : [ "epsilon-eridani.png" , "http://www.epsilon-eridani.com/" ] ,
  "emerald management suite" : [ "emerald.png" , "http://www.iea-software.com/products/emerald5.cfm" ] ,
  "emailing.newmediaplan.it" : [ "newmediaplan.png" , "http://www.newmediaplan.com/" ] ,
  "ensemble email services" : [ "ensemble.png" ] ,
  "egroups message poster" : [ "yahoo.png" , "http://www.yahoo.com/" ] ,
  "ebesucher mailserver" : [ "ebesucher.png" , "http://www.ebesucher.de/" ] ,
  "ebanka email robot" : [ "ebanka.png" , "http://www.ebanka.com/" ] ,
  "elitedevelopments" : [ "elitedev_com.png" , "http://www.elitedev.com/" ] ,
  "expressionengine" : [ "expressionengine.png" , "http://expressionengine.com/" ] ,
  "experts exchange" : [ "experts-exchange.png" , "http://www.experts-exchange.com/" ] ,
  "erweiterungen.de" : [ "erweiterungen_de.png" , "http://www.erweiterungen.de/" ] ,
  "endymion mailman" : [ "endymion.png" , "http://www.endymion.com/" ] ,
  "ecn communicator" : [ "ecn.png" , "http://www.ecn5.com/ecn.communicator/front/howitworks.aspx" ] ,
  "ecampaignpro.com" : [ "ecampaignpro.png" , "http://www.ecampaignpro.com/" ] ,
  "e-academy.mailer" : [ "e-academy_cz.png" , "http://www.e-academy.cz/" ] ,
  "exclamationsoft" : [ "exclamationsoft.png" , "http://www.exclamationsoft.com/exclamationsoft/netmailbot/" ] ,
  "eharmony mailer" : [ "eharmony.png" , "http://www.eharmony.com/" ] ,
  "ezine director" : [ "ezinedirector.png" , "http://www.ezinedirector.com/" ] ,
  "event software" : [ "event-software.png" , "http://www.event-software.com/" ] ,
  "efs technology" : [ "efs_technology.png" , "http://efstech.dk/" ] ,
  "eblast express" : [ "eblast.png" , "http://www.emerchant-direct.com/Originals_Ocean/EBLAST.htm" ] ,
  "ez components" : [ "ezcomponents.png" , "http://www.ezcomponents.org/" ] ,
  "everymail.net" : [ "everymail_net.png" , "http://www.everymail.net/" ] ,
  "espace-boutik" : [ "espace-boutik.png" , "http://www.espace-boutik.com/" ] ,
  "ef newsletter" : [ "efsoftware.png" , "http://www.efsoftware.com/" ] ,
  "ecartsoft.com" : [ "ecartsoft_com.png" , "http://www.ecartsoft.com/" ] ,
  "e-mandala.net" : [ "e-mandala_net.png" , "http://www.e-mandala.net/" ] ,
  "expressomail" : [ "expressomail.png" , "http://www.expressolivre.org/" ] ,
  "eweka beheer" : [ "eweka.png" , "http://www.eweka.nl/" ] ,
  "evolution 2." : [ "evolution2.png" , "http://www.gnome.org/projects/evolution/" ] ,
  "eloqua email" : [ "eloqua.png" , "http://www.eloqua.com/" ] ,
  "eloop mailer" : [ "eloop.png" , "http://www.goldlasso.com/" ] ,
  "electromundo" : [ "electromundo.png" , "http://www.electromundo.com/" ] ,
  "ec-messenger" : [ "ecircle.png" , "http://www.ecircle.com/" ] ,
  "ebay webmail" : [ "ebay.png" , "http://www.ebay.com/" ] ,
  "expressmail" : [ "expressmail.png" , "http://www.nec.co.jp/cced/ExpressMail/" ] ,
  "epoc e-mail" : [ "epoc.png" , "http://www.symbian.com/" ] ,
  "emailgarage" : [ "emailgarage.png" ] ,
  "ebay mailer" : [ "ebay.png" , "http://www.ebay.com/" ] ,
  "easycall.pl" : [ "easycall_pl.png" , "http://www.easycall.pl/" ] ,
  "e-undertown" : [ "e-undertown.png" , "http://www.e-undertown.com/en/software.asp" ] ,
  "e-msg.co.uk" : [ "e-msg_co_uk.png" , "http://www.e-msg.co.uk/" ] ,
  "e-messenger" : [ "e-messenger.png" , "http://www.e-village.nl/" ] ,
  "ezweb mail" : [ "au-kddi.png" , "http://www.au.kddi.com/english/ezweb/" ] ,
  "ez publish" : [ "ez_no.png" , "http://ez.no/ezpublish" ] ,
  "epoc email" : [ "epoc.png" , "http://www.symbian.com/" ] ,
  "emm-xpress" : [ "emm-xpress.png" , "http://www.emm-xpress.de/" ] ,
  "emacs+gnus" : [ "gnus.png" , "http://gnus.org/" ] ,
  "emacs gnus" : [ "gnus.png" , "http://gnus.org/" ] ,
  "eircom net" : [ "eircom_net.png" , "http://www.eircom.net/" ] ,
  "egroups-ew" : [ "yahoo.png" , "http://www.yahoo.com/" ] ,
  "ebizmailer" : [ "ebizmailer.png" ] ,
  "e-seikatsu" : [ "e-seikatsu.png" , "http://www.e-seikatsu.info/" ] ,
  "evolution" : [ "evolution.png" , "http://www.gnome.org/projects/evolution/" ] ,
  "entireweb" : [ "entireweb.png" , "http://www.entireweb.com/" ] ,
  "easy-mail" : [ "easy-mail.png" , "http://www.easy-mail.de/" ] ,
  "earthlink" : [ "earthlink.png" , "http://www.earthlink.net/" ] ,
  "earmaster" : [ "earmaster_com.png" , "http://www.earmaster.com/" ] ,
  "evernote" : [ "evernote.png" , "http://www.evernote.com/" ] ,
  "esupport" : [ "esupport.png" , "http://www.kayako.com/esupport.php" ] ,
  "emailtob" : [ "emailtob.png" , "http://www.emailtob.com/" ] ,
  "emailink" : [ "emailink.png" , "http://www.innomatix.com/" ] ,
  "email.bg" : [ "email_bg.png" , "http://www.email.bg/" ] ,
  "element5" : [ "element5.png" , "http://www.element5.de/" ] ,
  "eibport_" : [ "eibport.png" , "http://www.eib-home.de/" ] ,
  "eem.mail" : [ "express-email-marketing.png" , "http://gowebsite.com/express_email.html" ] ,
  "ebilling" : [ "ebilling.png" ] ,
  "eadirect" : [ "oracle_eadirect.png" , "http://www.oracle.com/" ] ,
  "e-mailer" : [ "e-mailer.png" , "http://www.assesso.com.br/Zope.pcgi/index_html?Secao=34" ] ,
  "explido" : [ "explido.png" , "http://www.explido-software.de/permission_marketing.0.html" ] ,
  "ewe tel" : [ "ewe-tel.png" , "http://www.ewetel.de/" ] ,
  "esender" : [ "esender.png" , "http://www.esender.de/" ] ,
  "equinux" : [ "equinux.png" , "http://www.equinux.de/" ] ,
  "epirent" : [ "epirent.png" , "http://www.epirent.de/" ] ,
  "energit" : [ "energit.png" , "http://www.energit.it/" ] ,
  "emumail" : [ "emumail.png" , "http://www.emumail.com/" ] ,
  "eastfax" : [ "eastfax.png" , "http://www.eastfax.com/" ] ,
  "eyepin" : [ "eyepin.png" , "http://www.eyepin.com/" ] ,
  "eudora" : [ "eudora.png" , "http://www.eudora.com/" ] ,
  "esprit" : [ "esprit-club.png" , "http://www.esprit-club.com/" ] ,
  "epylog" : [ "epylog.png" , "http://linux.duke.edu/projects/epylog/" ] ,
  "emplex" : [ "emplex.png" , "http://www.emplex.jp/" ] ,
  "email " : [ "cleancode-email.png" , "http://www.cleancode.org/projects/email" ] ,
  "emill/" : [ "emill.png" , "http://www.emill.net/" ] ,
  "emag -" : [ "emag_ro.png" , "http://www.emag.ro/" ] ,
  "elaine" : [ "elaine.png" , "http://www.elaine.de/" ] ,
  "edmail" : [ "edmail.png" ] ,
  "econdo" : [ "econdo.png" , "http://www.econdo.de/" ] ,
  "e-surf" : [ "e-surf_pl.png" , "http://www.e-surf.pl/" ] ,
  "empal" : [ "empas.png" , "http://mail.empas.com/" ] ,
  "emacs" : [ "emacs.png" , "http://www.gnu.org/software/emacs/" ] ,
  "elion" : [ "elion_hot.png" , "http://www.hot.ee/" ] ,
  "eldos" : [ "eldos.png" , "http://www.eldos.com/sbb/" ] ,
  "edmax" : [ "edmax.png" , "http://www.edcom.jp/soft.html" ] ,
  "exv2" : [ "exv2.png" , "http://www.exv2.de/" ] ,
  "exmh" : [ "exmh.png" , "http://exmh.org/" ] ,
  "exim" : [ "exim.png" , "http://www.exim.org/" ] ,
  "emh/" : [ "emacs.png" , "http://www.gnu.org/software/emacs/" ] ,
  "ebiz" : [ "ebiz-america.png" , "http://www.ebiz-america.com/" ] ,
  "eas " : [ "nokia.png" , "http://europe.nokia.com/A4275026" ] ,
  "ems" : [ "ems.png" , "http://www.emailing-solution.com/" ] ,
  "elm" : [ "elm.png" , "http://www.instinct.org/elm/" ] ,
  "efa" : [ "efa.png" , "http://home.snafu.de/nmichael/software/efa/" ] ,
}

==> dispmua_1.6.9.orig.tar.bz2: dispmua-1.6.9/chrome/chrome.jar!/content/data-65.js <==
dispMUA.arDispMUAAllocation["e"] =
{
  "e-mail spooler created by stepstone - easycruit" : [ "stepstone.png" , "http://www.easycruit.com/" ] ,
  "esmtp (eudora internet mail server" : [ "eudora.png" , "http://www.eudora.com/" ] ,
  "emilious sender by epsilon eridani" : [ "epsilon-eridani.png" , "http://www.epsilon-eridani.com/" ] ,
  "emerald management suite" : [ "emerald.png" , "http://www.iea-software.com/products/emerald5.cfm" ] ,
  "emailing.newmediaplan.it" : [ "newmediaplan.png" , "http://www.newmediaplan.com/" ] ,
  "ensemble email services" : [ "ensemble.png" ] ,
  "egroups message poster" : [ "yahoo.png" , "http://www.yahoo.com/" ] ,
  "ebesucher mailserver" : [ "ebesucher.png" , "http://www.ebesucher.de/" ] ,
  "ebanka email robot" : [ "ebanka.png" , "http://www.ebanka.com/" ] ,
  "elitedevelopments" : [ "elitedev_com.png" , "http://www.elitedev.com/" ] ,
  "expressionengine" : [ "expressionengine.png" , "http://expressionengine.com/" ] ,
  "experts exchange" : [ "experts-exchange.png" , "http://www.experts-exchange.com/" ] ,
  "erweiterungen.de" : [ "erweiterungen_de.png" , "http://www.erweiterungen.de/" ] ,
  "endymion mailman" : [ "endymion.png" , "http://www.endymion.com/" ] ,
  "ecn communicator" : [ "ecn.png" , "http://www.ecn5.com/ecn.communicator/front/howitworks.aspx" ] ,
  "ecampaignpro.com" : [ "ecampaignpro.png" , "http://www.ecampaignpro.com/" ] ,
  "e-academy.mailer" : [ "e-academy_cz.png" , "http://www.e-academy.cz/" ] ,
  "exclamationsoft" : [ "exclamationsoft.png" , "http://www.exclamationsoft.com/exclamationsoft/netmailbot/" ] ,
  "eharmony mailer" : [ "eharmony.png" , "http://www.eharmony.com/" ] ,
  "ezine director" : [ "ezinedirector.png" , "http://www.ezinedirector.com/" ] ,
  "event software" : [ "event-software.png" , "http://www.event-software.com/" ] ,
  "efs technology" : [ "efs_technology.png" , "http://efstech.dk/" ] ,
  "eblast express" : [ "eblast.png" , "http://www.emerchant-direct.com/Originals_Ocean/EBLAST.htm" ] ,
  "ez components" : [ "ezcomponents.png" , "http://www.ezcomponents.org/" ] ,
  "everymail.net" : [ "everymail_net.png" , "http://www.everymail.net/" ] ,
  "espace-boutik" : [ "espace-boutik.png" , "http://www.espace-boutik.com/" ] ,
  "ef newsletter" : [ "efsoftware.png" , "http://www.efsoftware.com/" ] ,
  "ecartsoft.com" : [ "ecartsoft_com.png" , "http://www.ecartsoft.com/" ] ,
  "e-mandala.net" : [ "e-mandala_net.png" , "http://www.e-mandala.net/" ] ,
  "expressomail" : [ "expressomail.png" , "http://www.expressolivre.org/" ] ,
  "eweka beheer" : [ "eweka.png" , "http://www.eweka.nl/" ] ,
  "evolution 2." : [ "evolution2.png" , "http://www.gnome.org/projects/evolution/" ] ,
  "essentialpim" : [ "essentialpim.png" , "http://www.essentialpim.com/" ] ,
  "eloqua email" : [ "eloqua.png" , "http://www.eloqua.com/" ] ,
  "eloop mailer" : [ "eloop.png" , "http://www.goldlasso.com/" ] ,
  "electromundo" : [ "electromundo.png" , "http://www.electromundo.com/" ] ,
  "ec-messenger" : [ "ecircle.png" , "http://www.ecircle.com/" ] ,
  "ebay webmail" : [ "ebay.png" , "http://www.ebay.com/" ] ,
  "expressmail" : [ "expressmail.png" , "http://www.nec.co.jp/cced/ExpressMail/" ] ,
  "epoc e-mail" : [ "epoc.png" , "http://www.symbian.com/" ] ,
  "emailgarage" : [ "emailgarage.png" ] ,
  "elettershop" : [ "elettershop.png" , "http://www.elettershop.de/" ] ,
  "ebay mailer" : [ "ebay.png" , "http://www.ebay.com/" ] ,
  "easycall.pl" : [ "easycall_pl.png" , "http://www.easycall.pl/" ] ,
  "e-undertown" : [ "e-undertown.png" , "http://www.e-undertown.com/en/software.asp" ] ,
  "e-msg.co.uk" : [ "e-msg_co_uk.png" , "http://www.e-msg.co.uk/" ] ,
  "e-messenger" : [ "e-messenger.png" , "http://www.e-village.nl/" ] ,
  "ezweb mail" : [ "au-kddi.png" , "http://www.au.kddi.com/english/ezweb/" ] ,
  "ez publish" : [ "ez_no.png" , "http://ez.no/ezpublish" ] ,
  "epoc email" : [ "epoc.png" , "http://www.symbian.com/" ] ,
  "emm-xpress" : [ "emm-xpress.png" , "http://www.emm-xpress.de/" ] ,
  "emacs+gnus" : [ "gnus.png" , "http://gnus.org/" ] ,
  "emacs gnus" : [ "gnus.png" , "http://gnus.org/" ] ,
  "eircom net" : [ "eircom_net.png" , "http://www.eircom.net/" ] ,
  "egroups-ew" : [ "yahoo.png" , "http://www.yahoo.com/" ] ,
  "ebizmailer" : [ "ebizmailer.png" ] ,
  "e-seikatsu" : [ "e-seikatsu.png" , "http://www.e-seikatsu.info/" ] ,
  "evolution" : [ "evolution.png" , "http://www.gnome.org/projects/evolution/" ] ,
  "entireweb" : [ "entireweb.png" , "http://www.entireweb.com/" ] ,
  "easy-mail" : [ "easy-mail.png" , "http://www.easy-mail.de/" ] ,
  "earthlink" : [ "earthlink.png" , "http://www.earthlink.net/" ] ,
  "earmaster" : [ "earmaster_com.png" , "http://www.earmaster.com/" ] ,
  "evernote" : [ "evernote.png" , "http://www.evernote.com/" ] ,
  "esupport" : [ "esupport.png" , "http://www.kayako.com/esupport.php" ] ,
  "emailtob" : [ "emailtob.png" , "http://www.emailtob.com/" ] ,
  "emailink" : [ "emailink.png" , "http://www.innomatix.com/" ] ,
  "email.bg" : [ "email_bg.png" , "http://www.email.bg/" ] ,
  "element5" : [ "element5.png" , "http://www.element5.de/" ] ,
  "eibport_" : [ "eibport.png" , "http://www.eib-home.de/" ] ,
  "eem.mail" : [ "express-email-marketing.png" , "http://gowebsite.com/express_email.html" ] ,
  "ebilling" : [ "ebilling.png" ] ,
  "eadirect" : [ "oracle_eadirect.png" , "http://www.oracle.com/" ] ,
  "e-mailer" : [ "e-mailer.png" , "http://www.assesso.com.br/Zope.pcgi/index_html?Secao=34" ] ,
  "explido" : [ "explido.png" , "http://www.explido-software.de/permission_marketing.0.html" ] ,
  "ewe tel" : [ "ewe-tel.png" , "http://www.ewetel.de/" ] ,
  "esender" : [ "esender.png" , "http://www.esender.de/" ] ,
  "equinux" : [ "equinux.png" , "http://www.equinux.de/" ] ,
  "epirent" : [ "epirent.png" , "http://www.epirent.de/" ] ,
  "energit" : [ "energit.png" , "http://www.energit.it/" ] ,
  "emumail" : [ "emumail.png" , "http://www.emumail.com/" ] ,
  "eastfax" : [ "eastfax.png" , "http://www.eastfax.com/" ] ,
  "eyepin" : [ "eyepin.png" , "http://www.eyepin.com/" ] ,
  "eudora" : [ "eudora.png" , "http://www.eudora.com/" ] ,
  "esprit" : [ "esprit-club.png" , "http://www.esprit-club.com/" ] ,
  "epylog" : [ "epylog.png" , "http://linux.duke.edu/projects/epylog/" ] ,
  "emplex" : [ "emplex.png" , "http://www.emplex.jp/" ] ,
  "email " : [ "cleancode-email.png" , "http://www.cleancode.org/projects/email" ] ,
  "emill/" : [ "emill.png" , "http://www.emill.net/" ] ,
  "emag -" : [ "emag_ro.png" , "http://www.emag.ro/" ] ,
  "elaine" : [ "elaine.png" , "http://www.elaine.de/" ] ,
  "edmail" : [ "edmail.png" ] ,
  "econdo" : [ "econdo.png" , "http://www.econdo.de/" ] ,
  "e-surf" : [ "e-surf_pl.png" , "http://www.e-surf.pl/" ] ,
  "empal" : [ "empas.png" , "http://mail.empas.com/" ] ,
  "emacs" : [ "emacs.png" , "http://www.gnu.org/software/emacs/" ] ,
  "elion" : [ "elion_hot.png" , "http://www.hot.ee/" ] ,
  "eldos" : [ "eldos.png" , "http://www.eldos.com/sbb/" ] ,
  "edmax" : [ "edmax.png" , "http://www.edcom.jp/soft.html" ] ,
  "exv2" : [ "exv2.png" , "http://www.exv2.de/" ] ,
  "exmh" : [ "exmh.png" , "http://exmh.org/" ] ,
  "exim" : [ "exim.png" , "http://www.exim.org/" ] ,
  "emh/" : [ "emacs.png" , "http://www.gnu.org/software/emacs/" ] ,
  "ebiz" : [ "ebiz-america.png" , "http://www.ebiz-america.com/" ] ,
  "eas " : [ "nokia.png" , "http://europe.nokia.com/A4275026" ] ,
  "ems" : [ "ems.png" , "http://www.emailing-solution.com/" ] ,
  "elm" : [ "elm.png" , "http://www.instinct.org/elm/" ] ,
  "efa" : [ "efa.png" , "http://home.snafu.de/nmichael/software/efa/" ] ,
}
